#
# spec file for package deepin-api
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2021 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define   provider        github
%define   provider_tld    com
%define   project         linuxdeepin
%define   repo            dde-api
%define   provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%define   import_path     %{provider_prefix}

Name:           deepin-api
Version:        5.5.25
Release:        2.3
Summary:        Go-lang bingding for dde-daemon
License:        GPL-3.0-or-later
URL:            https://github.com/linuxdeepin/dde-api
Source0:        https://github.com/linuxdeepin/dde-api/archive/%{version}/%{repo}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source99:       deepin-api-rpmlintrc
# PATCH-FIX-OPENSUSE default-grub2-theme.patch hillwood@opensuse.org - Set openSUSE grub theme as default
Patch0:         default-grub2-theme.patch
# PATCH-FIX-OPENSUSE disable-gosrc-install-in-makefile.patch hillwood@opensuse.org
# Use goinstall macro instead of makefile
Patch1:         disable-gosrc-install-in-makefile.patch
Patch2:         harden_deepin-login-sound.service.patch
Patch3:         harden_deepin-shutdown-sound.service.patch
Group:          System/GUI/Other
BuildRequires:  deepin-gettext-tools
BuildRequires:  deepin-gir-generator
BuildRequires:  deepin-sound-theme
BuildRequires:  fdupes
BuildRequires:  golang-github-linuxdeepin-go-dbus-factory >= 1.9.17
BuildRequires:  golang-github-linuxdeepin-go-gir-generator
BuildRequires:  golang-github-linuxdeepin-go-lib
BuildRequires:  golang-github-linuxdeepin-go-x11-client
BuildRequires:  golang-packaging
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(cairo-ft)
BuildRequires:  pkgconfig(gdk-pixbuf-xlib-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(polkit-qt5-1)
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xi)
Requires:       deepin-desktop-base
Requires:       rfkill
Requires(pre):  group(audio)
AutoReqProv:    Off
%{?systemd_ordering}

%description
The deepin-api is DDE API provides some dbus interfaces that is used for screen
zone detecting, thumbnail generating, sound playing, etc.

%package -n golang-%{provider}-%{project}-%{repo}
Summary:        DDE API golang codes
Group:          Development/Languages/Golang
Requires:       deepin-gir-generator
Requires:       golang-github-linuxdeepin-go-dbus-factory >= 1.9.17
Requires:       golang-github-linuxdeepin-go-lib
Requires:       golang-github-linuxdeepin-go-x11-client
Requires:       pkgconfig(alsa)
Requires:       pkgconfig(cairo-ft)
Requires:       pkgconfig(gdk-pixbuf-xlib-2.0)
Requires:       pkgconfig(gio-2.0)
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(gtk+-3.0)
Requires:       pkgconfig(gudev-1.0)
Requires:       pkgconfig(libcanberra)
Requires:       pkgconfig(libpulse-simple)
Requires:       pkgconfig(librsvg-2.0)
Requires:       pkgconfig(polkit-qt5-1)
Requires:       pkgconfig(poppler-glib)
Requires:       pkgconfig(systemd)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xcursor)
Requires:       pkgconfig(xfixes)
Requires:       pkgconfig(xi)
BuildArch:      noarch
AutoReq:        Off
%{go_provides}

%description -n golang-%{provider}-%{project}-%{repo}
The deepin-api is DDE API provides some dbus interfaces that is used for screen
zone detecting, thumbnail generating, sound playing, etc.

This package contains library source intended forbuilding other packages which
use import path with pkg.deepin.io/dde/api prefix.

%prep
%autosetup -p1 -a1 -n %{repo}-%{version}
mkdir -p $HOME/rpmbuild/BUILD/go/src/
cp vendor/* $HOME/rpmbuild/BUILD/go/src/ -r
rm -rf vendor

%build
export GO111MODULE=off
%goprep %{import_path}
%gobuild ...
%make_build

%install
mv $HOME/rpmbuild/BUILD/go/src/github.com/linuxdeepin .
rm -rf $HOME/rpmbuild/BUILD/go/src/github.com/*\
       $HOME/rpmbuild/BUILD/go/src/golang.org \
       $HOME/rpmbuild/BUILD/go/src/gopkg.in
mv linuxdeepin $HOME/rpmbuild/BUILD/go/src/github.com/
%goinstall
%gosrc
install -m0644 themes/*.c %{buildroot}%{go_contribsrcdir}/%{import_path}/themes/
install -m0644 gtk-thumbnailer/*.c %{buildroot}%{go_contribsrcdir}/%{import_path}/gtk-thumbnailer/
install -m0644 dxinput/utils/*.c %{buildroot}%{go_contribsrcdir}/%{import_path}/dxinput/utils/
install -m0644 thumbnails/icon/*.c %{buildroot}%{go_contribsrcdir}/%{import_path}/thumbnails/icon/
install -m0644 thumbnails/text/*.c %{buildroot}%{go_contribsrcdir}/%{import_path}/thumbnails/text/
install -m0644 thumbnails/images/*.c %{buildroot}%{go_contribsrcdir}/%{import_path}/thumbnails/images/
install -m0644 thumbnails/font/*.c %{buildroot}%{go_contribsrcdir}/%{import_path}/thumbnails/font/
install -m0644 thumbnails/pdf/*.c %{buildroot}%{go_contribsrcdir}/%{import_path}/thumbnails/pdf/
%gofilelist

mkdir -p out/bin/
mv %{buildroot}%{_bindir}/* out/bin/
%make_install SYSTEMD_SERVICE_DIR=%{_unitdir}

install -d %{buildroot}%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcdeepin-shutdown-sound
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcdeepin-login-sound

# It requests an invali command in openSUSE, please use Yast2 to change locale
rm %{buildroot}%{_datadir}/polkit-1/actions/com.deepin.api.locale-helper.policy

%fdupes %{buildroot}

%pre
getent group deepin-sound-player >/dev/null || %{_sbindir}/groupadd --system deepin-sound-player
getent passwd deepin-sound-player >/dev/null || %{_sbindir}/useradd --system -c "deepin-sound-player User" \
         -d %{_localstatedir}/deepin-sound-player -m -g deepin-sound-player -s %{_sbindir}/nologin \
         -G audio deepin-sound-player
%service_add_pre deepin-shutdown-sound.service deepin-login-sound.service

%post
%service_add_post deepin-shutdown-sound.service deepin-login-sound.service

%preun
%service_del_preun deepin-shutdown-sound.service deepin-login-sound.service

%postun
%service_del_postun deepin-shutdown-sound.service deepin-login-sound.service

%files
%doc README.md
%license LICENSE
%{_bindir}/*
%exclude %{_bindir}/deepin-api-polkit-installer
%exclude %{_bindir}/deepin-api-dbus-installer
%{_sbindir}/rcdeepin-shutdown-sound
%{_sbindir}/rcdeepin-login-sound
%{_unitdir}/*.service
%{_datadir}/dde-api
%exclude %{_datadir}/dde-api/*.tar.gz
%{_datadir}/dbus-1/services/*.service
%{_datadir}/dbus-1/system-services/*.service
%dir %{_datadir}/dbus-1/system.d/
%{_datadir}/dbus-1/system.d/*.conf
%{_datadir}/icons/hicolor/*/actions/*
%{_datadir}/polkit-1/actions/*.policy
%{_prefix}/lib/deepin-api
%dir /var/lib/polkit-1
%dir /var/lib/polkit-1/localauthority
%dir /var/lib/polkit-1/localauthority/10-vendor.d
/var/lib/polkit-1/localauthority/10-vendor.d/com.deepin.api.device.pkla

%files -n golang-%{provider}-%{project}-%{repo} -f file.lst

%changelog
* Mon Oct 16 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Ensure group 'audio' exist prior to package installation:
  deepin-sound-player user is supposed to be added to the group.
* Sat Aug 13 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.25
  * Fix bugs
* Sat Apr  2 2022 Hillwood Yang <hillwoodroc@gmail.com>
- Update version to 5.5.12
  * Change pkg.deepin.io to github.com
  * Update language_support data
  * Fix bugs
* Wed Feb 23 2022 Hillwood Yang <hillwood@opensuse.org>
- Use last stable version of go to build
* Fri Feb 18 2022 Hillwood Yang <hillwood@opensuse.org>
- update version to 5.5.5
  * Add polkit api
  * Fix bugs
* Thu Dec 16 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.32
  * Fix bugs
* Wed Oct 27 2021 Hillwood Yang <hillwood@opensuse.org>
- Set badness for leap. These dbus profiles have been whilelisted on
  Tumbleweed.
- Fix build on Leap 15.4+
* Thu Sep 30 2021 Hillwood Yang <hillwood@opensuse.org>
- Fix build for Tumbleweed x86_32
* Mon Sep 20 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.11
  * Fix ImagBlur security issue
* Fri Sep  3 2021 Johannes Segitz <jsegitz@suse.com>
- Allow access to sound device. Updated
  * harden_deepin-login-sound.service.patch
  * harden_deepin-shutdown-sound.service.patch
* Wed Sep  1 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Added patch(es):
  * harden_deepin-login-sound.service.patch
  * harden_deepin-shutdown-sound.service.patch
* Tue Aug 17 2021 Hillwood Yang <hillwood@opensuse.org>
- Fix boo#1070943, drop deepin-api-dbus-installer and deepin-api-polkit-installer
* Fri Jul 23 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.9
  * Add SetTransformationMatrix to Touchscreen
  * Change go-dbus-factory struct as interface
  * Update test modules
* Fri May 21 2021 Hillwood Yang <hillwood@opensuse.org>
- Keep golang verion on 1.15 on Tumbleweed, the project does not support
  golang 1.16+
* Sat May  1 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.5
  * Fix deepin-login-sound.service is invalid
  * Disable calendar service
* Sat Mar 13 2021 Hillwood Yang <hillwood@opensuse.org>
- Add deepin-api-polkit-installer and deepin-api-dbus-installer
* Wed Mar 10 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version 5.4.2
  * New GetExportedMethods method
  * Update translations
* Thu Feb 25 2021 Hillwood Yang <hillwood@opensuse.org>
- File polkit and dbus service profiles, workaround boo#1070943
* Sun Feb 21 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.3.2
  * fix bugs
  * chore: Modify control Description data
  * feat: Initial packit setup
  * chore:add build description
  * Update calendar data
  * change(api): lunar-calendar add method GetFestivalsInRange
  * chore(dxinput): comment wayland dump
  * fix(sound-theme-player): reduce auto stop duration
  * fix(dxinput): fix test failure in jenkins
  * chore: priority use update-grub2
  * chore(blurimage): skip TestIsTooBright on arch i386
  * fix(lunar-calendar): decrease the log level
  * fix: warnings reported by go vet
  * feat(lunar-calender): add festival info
  * chore: auto pull translation files from transifex
  * fix(shutdown-sound): after sound file is played, it still does not exit
  * chore: auto pull translation files from transifex
- Add disable-gosrc-install-in-makefile.patch, use %%%%goinstall macro instead of
  makefile
* Thu Jul 18 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.18.5
  * Update translations
  * chore: correct a typo
  * Fix checkAuthorization is not secure
  * feat(cursor-helper): set com.deepin.wm cursorTheme
  * Fix failed to set background if theme output dir not exist
* Sun Apr 14 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.18.3
  * chore(deb): override dh_systemd_start
  * fix(adjust-grub-theme): terminal font has cursor image residue
  * chore: auto pull translation files from transifex
  * feat(sound-theme-player): add retry for alsactl restore
* Thu Apr 11 2019 Hillwood Yang <hillwood@opensuse.org>
- Rewrite spec with golang-packaging
- Update version to 3.18.0
  * change(api): sound-theme-player add more methods
  * chore: modify GOPATH directroy order
  * chore: use pkg.deepin.io/gir
  * chore: pkg_depends remove fcitx-sogoupinyin-uk
  * chore(language_support): do not use lastore dbus methods
  * fix: deepin grub theme text typo
  * fix: can not play shutdown music
  * fix: build miss pkg userenv
  * feat: add package userenv
  * feat: grub-theme add key e and c usage
  * auto sync po files from transifex
  * chore: depends remove grub-common
  * feat(soundutils): and method for get sound file
  * chore: change background image format from png to jpeg
  * chore: compile with sw arch no longer needs to use gccgo
  * fix(adjust-grub-theme): only 4 lines of options can be displayed when the
    resolution is 1280x1024
  * auto sync po files from transifex
  * chore(adjust-grub-theme): use lib imgutil
  * feat: remove code about setting `GRUB_GFXMODE` from the debian/postinst
    script
  * chore: `pkg_depends` add rule for thunderbird-l10n-
  * fix: some types
  * fix: crash on dde-open when no appinfo available
  * fix(adjust-grub-theme): set background failed
  * fix(adjust-grub-theme): no append `GRUB_GFXMODE=1024x768`
  * feat(adjust-grub-theme): reset `GRUB_GFXMODE` to 1024x768 only once
  * fix: icon theme deepin-dark thumbnail not well
  * fix: correctly parse rfkill output
  * feat(adjust-grub-theme): add scrollbar thumb
  * fix(adjust-grub-theme): failed to display 5 items
  * chore(adjust-grub-theme): update background.origin.png
  * chore(adjust-grub-theme): update version
  * fix: update-grub not executed after adjust grub theme
  * chore(grub-theme): add os.svg
  * fix(adjust-grub-theme): set background copy file failed
  * feat(dxinput): add libinput pointer rotation supported
  * chore: no call grub-mkconfig
  * chore(adjust-grub-theme): small appearance adjustment
  * fix: update-grub not executed after adjust grub theme
  * feat(adjust-grub-theme): use pkg.deepin.io/lib/log
  * fix(adjust-grub-theme): save boot menu position rel value into theme.txt
  * auto sync po files from transifex
  * feat: add binary adjust-grub-theme
  * fix(`pkg_depends`): not found cangjie input method
  * chore(`pkg_depneds`): zh-hant do not install fcitx-ui-qimpanel
  * chore: auto sync ts files from transifex
  * chore: add unblock-bluetooth-device policy to tx config
  * fix(device): rfkillBin use absolute path
  * feat(locale-helper): more safe call locale-gen
  * feat(device): limit com.deepin.api.Device service
  * feat: do not use the root user to run sound theme player
  * chore(debian): update require versions
  * feat(mouse): interface to config accel profile via libinput
  * auto sync po files from transifex
  * fix(drandr): rate calculation inaccuracies
  * chore(locale-helper): no use pkg.deepin.io/lib/polkit
  * chore: use go-dbus-factory
  * fix(dde-open): panic when run dde-open xxxxxxx:///xxxxxxxx
  * chore(debian): update debian control
  * chore(drandr): use go-x11-client
  * chore: update makefile for arch `sw_64`
  * auto sync po files from transifex
  * feat(theme-thumb): use rsvg-convert convert svg to png
  * fix(theme-thumb): printf argument wrong
  * feat: add dde-open
  * refactor: fix some typos
* Fri Mar 23 2018 hillwood@opensuse.org
- Update version to 3.1.22
  * chore: use lib dbusutil new api
  * auto sync po files from transifex
  * feat(sound-theme-player): use newly lib dbusutil
  * feat(cursor-helper): use newly lib dbusutil
  * feat(hans2pinyin): use newly lib dbusutil
  * feat(lunar-calendar): use newly lib dbusutil
  * feat(locale-helper): use newly lib dbusutil
  * feat(graphic): use newly lib dbusutil
  * feat(device): use newly lib dbusutil
  * chore: update license
* Thu Mar  1 2018 hillwood@opensuse.org
- Update version to 3.1.20
  * doc: update links in README
  * fix a typo
  * rename mousearea to x-event-monitor
  * soundutils: use `sound_effect` lib
  * add lib `language_support`
  * sound-theme-player: use newly `sound_effect` lib
  * add libs for gccgo build
  * fix Adapt lintian
  * remove x-event-monitor
* Tue Nov 28 2017 hillwood@opensuse.org
- Update to 3.1.17
  * Fix some cursor theme thumbnails generate failed
* Fri Nov 10 2017 hillwood@opensuse.org
- Cleanup spec
  * Add Group tag
  * Use %%icon_theme_cache_post macro
  * Use openSUSE Macros instead of macros form Fedora.
* Sat Nov  4 2017 steve.todorov@carlspring.com
- Updating to 3.1.16
  * New dependencies:
  - deepin-gettext-tools
  - golang-github-nfnt-resize
* Wed Nov  1 2017 steve.todorov@carlspring.com
- Updating to 3.1.15
* Tue Oct  3 2017 sensor.wen@gmail.com
- Initial package.
